@@ -105,7 +105,7 @@ impl ContactInfo {
     }
 
     /// New random ContactInfo for tests and simulations.
-    pub(crate) fn new_rand<R: rand::Rng>(rng: &mut R, pubkey: Option<Pubkey>) -> Self {
+    pub fn new_rand<R: rand::Rng>(rng: &mut R, pubkey: Option<Pubkey>) -> Self {
         let delay = 10 * 60 * 1000; // 10 minutes
         let now = timestamp() - delay + rng.gen_range(0, 2 * delay);
         let pubkey = pubkey.unwrap_or_else(solana_sdk::pubkey::new_rand);
@@ -193,10 +193,17 @@ impl ContactInfo {
     /// port must not be 0
     /// ip must be specified and not multicast
     /// loopback ip is only allowed in tests
-    pub fn is_valid_address(addr: &SocketAddr) -> bool {
+    // Keeping this for now not to break tvu-peers and turbine shuffle order of
+    // nodes when arranging nodes on retransmit tree. Private IP addresses in
+    // turbine are filtered out just before sending packets.
+    pub(crate) fn is_valid_tvu_address(addr: &SocketAddr) -> bool {
         (addr.port() != 0) && Self::is_valid_ip(addr.ip())
     }
 
+    pub fn is_valid_address(addr: &SocketAddr) -> bool {
+        Self::is_valid_tvu_address(addr) && solana_streamer::socket::is_global(addr)
+    }
+
     pub fn client_facing_addr(&self) -> (SocketAddr, SocketAddr) {
         (self.rpc, self.tpu)
     }
